<?php

class portstatus {

	const INDEX = 0;
	const HOST = 1;
	const ADMIN = 2;
	const DESC = 3;
	const OPER = 4;
	const NAME = 5;
	const ALIAS = 6;
	const LOCDESC = 7;
	const TYPE = 8;
	const IDLE = 9;
	const SPEED = 10;

	/**
	 * Returns the check_portstatus data for a Host if data exists, returns it
	 * in the form of an associative array
	 *
	 * @param $host Host_Model
	 * @param $spooldir string
	 * @return array
	 */
	public static function get_data (Host_Model $host, $spooldir) {

		$path = $spooldir . '/status' . $host->get_address();

		/* Make sure we don't do any path-tricks, which means. If we do,
		 * realpath will simplify the path */
		if(realpath($path) != $path) {
			throw new Exception("The status file for host " . $host->get_name() . " can't be accessed at " . $path);
		}

		$lines = file($path);

		/**
		 * The value returned from SNMP is in centi-seconds
		 */
		$dormant_time = intval(array_shift($lines)) * 100;
		$number_of_ports = intval(array_shift($lines));
		$status_stat = stat($path);

		natsort($lines);
		$data = array_map(function ($line) {
			return preg_split("/\s*,\s*/", $line);
		}, $lines);

		return array(
			"dormant_time" => $dormant_time,
			"portcount" => $number_of_ports,
			"stats" => $status_stat,
			"data" => array_values($data)
		);

	}

	/**
	 * Returns a string representation of the ifType value, it will
	 * return an empty string if no other status is found.
	 *
	 * @param $port array A data array of a check_portstatus csv line
	 * @return string
	 */
	public static function get_snmp_typename ($port) {

		$config = Kohana::config('portstatus');
		$typenames = $config['portstatus']['typenames'];

		if (isset($typenames[$port[portstatus::TYPE]])) {
			return $typenames[$port[portstatus::TYPE]];
		} else return "unknown";

	}

	/**
	 * Returns a string representation of the ifAdminStatus value, it will
	 * return "down" if no other status is found.
	 *
	 * @param $port array A data array of a check_portstatus csv line
	 * @return string
	 */
	public static function get_readable_admin_status (array $port) {
		if ($port[portstatus::ADMIN] == 1) return "up";
		elseif ($port[portstatus::ADMIN] == 2) return "down";
		elseif ($port[portstatus::ADMIN] == 3) return "testing";
		else return "down";
	}

	/**
	 * Returns a string representation of the ifOperStatus value, it will
	 * return "disconnected" if no other status is found.
	 *
	 * @param $port array A data array of a check_portstatus csv line
	 * @return string
	 */
	public static function get_readable_oper_status (array $port) {
		$status = "disconnected";
		if ($port[portstatus::OPER] == 1) {
			$status = "connected";
		}
		return $status;
	}

}

